==> elasticsearch-6.2.2-sources.jar: org/elasticsearch/action/admin/cluster/snapshots/delete/DeleteSnapshotAction.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.admin.cluster.snapshots.delete;

import org.elasticsearch.action.Action;
import org.elasticsearch.client.ElasticsearchClient;

/**
 * Delete snapshot action
 */
public class DeleteSnapshotAction extends Action<DeleteSnapshotRequest, DeleteSnapshotResponse, DeleteSnapshotRequestBuilder> {

    public static final DeleteSnapshotAction INSTANCE = new DeleteSnapshotAction();
    public static final String NAME = "cluster:admin/snapshot/delete";

    private DeleteSnapshotAction() {
        super(NAME);
    }

    @Override
    public DeleteSnapshotResponse newResponse() {
        return new DeleteSnapshotResponse();
    }

    @Override
    public DeleteSnapshotRequestBuilder newRequestBuilder(ElasticsearchClient client) {
        return new DeleteSnapshotRequestBuilder(client, this);
    }
}

==> elasticsearch-6.8.7-sources.jar: org/elasticsearch/action/admin/cluster/snapshots/delete/DeleteSnapshotAction.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.admin.cluster.snapshots.delete;

import org.elasticsearch.action.Action;
import org.elasticsearch.client.ElasticsearchClient;
import org.elasticsearch.action.support.master.AcknowledgedResponse;

/**
 * Delete snapshot action
 */
public class DeleteSnapshotAction extends Action<DeleteSnapshotRequest, AcknowledgedResponse, DeleteSnapshotRequestBuilder> {

    public static final DeleteSnapshotAction INSTANCE = new DeleteSnapshotAction();
    public static final String NAME = "cluster:admin/snapshot/delete";

    private DeleteSnapshotAction() {
        super(NAME);
    }

    @Override
    public AcknowledgedResponse newResponse() {
        return new AcknowledgedResponse();
    }

    @Override
    public DeleteSnapshotRequestBuilder newRequestBuilder(ElasticsearchClient client) {
        return new DeleteSnapshotRequestBuilder(client, this);
    }
}
